<div class="readonly bg-gray-50 border font-medium max-w-2xl px-3 py-2 rounded-md shadow-sm text-gray-500 text-sm" {% include 'django/forms/widgets/attrs.html' %}>
    {% if summary|length > 1 %}
        {% for entry in summary %}
            <strong class="font-semibold text-gray-900">{{ entry.label }}</strong>{% if entry.value %}: {{ entry.value }}{% endif %}
        {% endfor %}
    {% else %}
        {% for entry in summary %}
            {{ entry.label }}
        {% endfor %}
    {% endif %}
</div>
